require 'spec_helper'

describe SpotTracks::Feed do
  let(:entry){ double(title: 'baz', url: 'qux') }
  let(:feedjira){ double(title: 'foo', url: 'http://bar', entries: [entry]) }
  let(:subject){ SpotTracks::Feed.new('mttwrnr') }

  before do
    param = "http://ws.audioscrobbler.com/1.0/user/mttwrnr/recenttracks.rss"
    Feedjira::Feed.stub(:fetch_and_parse).with(param){ feedjira }
    SpotTracks::Player.stub(:new){ double(search: {}) }
  end

  context 'attributes' do
    it 'should establish a username' do
      subject.username.should eq('mttwrnr')
    end

    it 'should return rss title' do
      subject.title.should eq('foo')
    end

    it 'should return rss url' do
      subject.url.should eq('http://bar')
    end
  end

  context '#tracks' do
    it 'should return an array of tracks' do
      subject.tracks.should be_a_kind_of(Array)
    end
  end

  context '#to_json' do
    it 'should return a json version of tracks values' do
      result = "{\"title\":\"foo\",\"url\":\"http://bar\",\"tracks\":[{}]}"
      subject.to_json.should eq(result)
    end
  end
end
