require 'spec_helper'

describe SpotTracks::Track do
  let(:data){ fixture(:api) }
  let(:subject){ SpotTracks::Track.new({
    name: 'foo', artist: 'bar',
    image: 'baz', uri: 'qux'
  }) }

  context 'attributes' do
    it 'accepts a hash of attributes' do
      subject.name.should eq('foo')
      subject.artist.should eq('bar')
      subject.image.should eq('baz')
      subject.uri.should eq('qux')
    end
  end

  context '#search' do
    it 'uses the player search' do
      SpotTracks::Player.any_instance.should_receive(:search).with('bar - foo').once
      SpotTracks::Track.search('bar - foo')
    end
  end

  context '#parse' do
    let(:track){ SpotTracks::Track.parse(data) }
    it 'converts json data' do
      track.name.should eq('Get Free')
      track.artist.should eq('Major Lazer')
      track.image.should eq('https://i.scdn.co/image/8c0c53664893cbce7f579b819d39d0e19d729710')
      track.uri.should eq('spotify:track:6nVEdIiB3h5b2TbQhFnQUk')
    end
  end

  context '#title' do
    it 'should combine the track and artist' do
      subject.title.should eq('bar - foo')
    end
  end

  context '#to_h' do
    let(:formatted){
      { title: 'bar - foo',
        name: 'foo', artist: 'bar',
        urls: { image: 'baz', uri: 'qux' } }
    }

    it 'returns the data in hash format' do
      subject.to_h.should eq(formatted)
    end
  end
end
